#!/usr/bin/env python3

import json
import os

header = """
# Content Format



"""

def print_entry(key, parser_raw):
    # | key | parser | comment |
    parser = '`' + str(parser_raw) + '`'

    if parser_raw == "text":
        parser = "String"
    elif parser_raw == "int":
        parser = "Integer"
    elif parser_raw == "[text]":
        parser = "\[String\]"
    elif parser_raw == "attr":
        parser = "[Attr](#attr)"
    elif parser_raw == "blocks":
        parser = "\[[Block](#blocks)\]"
    elif parser_raw == "[blocks]":
        parser = "\[\[[Block](#blocks)\]\]"
    elif parser_raw == "inlines":
        parser = "\[[Inline](#inlines)\]"
    elif parser_raw == "kvps":
        parser = "{foo: bar, alice: bob, ...}"
    elif isinstance(parser_raw,list):
        parser = '`' + '` \| `'.join(parser_raw) + '`'

    print("| {key} | {parser} | {comment} |".format(key=key, parser=parser, comment=""))

def print_table_header():
    print("| Key | Parser | Comment |")
    print("|-----|--------|---------|")


def print_etype(etype, c):
    print("")
    print("")
    print("### {etype}".format(etype=etype))
    print("")
    print_table_header()
    print_entry("etype", etype)
    for key, value in c.items():
        print_entry(key, value)


if __name__ == '__main__':
    j = {}
    with open('content.json') as f:
        j = json.loads(f.read())

    print(header)
    print("")
    print("")
    print("## Attr")
    print("")
    print("")
    print_table_header()
    print_entry("id", "text")
    print_entry("classes", "[text]")
    print_entry("extra", "kvps")


    print("")
    print("")
    print("## Blocks")
    is_blocks = True
    for etype, c in j.items():
        if c['eclass'] != 'block' and is_blocks:
            is_blocks = False
            print("")
            print("")
            print("## Inlines")
        print_etype(etype, c)


